#
# spec file for package ghc-hslua-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-cli
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.4.3
Release:        1.6
Summary:        Command-line interface for Lua
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-hslua-core-devel
BuildRequires:  ghc-hslua-core-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-hslua-repl-devel
BuildRequires:  ghc-hslua-repl-prof
BuildRequires:  ghc-lua-devel
BuildRequires:  ghc-lua-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
ExcludeArch:    %{ix86}

%description
Provides an embeddable command-line interface for Lua. The interface is
compatible with the standard Lua interpreter, i.e., the `lua` executable
provided in a default Lua installation.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Jun 28 2024 Peter Simons <psimons@suse.com>
- Update hslua-cli to version 1.4.3.
  [#]# hslua-cli-1.4.3
  Release pending.
  - Include copyright notice when printing version info; i.e., the
    behavior is now closer to that of the default `lua`
    interpreter.
  - Avoid "redundant import" warning when compiling with GHC 9.10.
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-cli to version 1.4.2.
  [#]# hslua-cli-1.4.2
  Released 2024-01-18.
  - Relaxed upper bound for text, allowing text-2.1.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-cli to version 1.4.1.
  [#]# hslua-cli-1.4.1
  Released 2023-03-18.
  - Always start the REPL if the `-i` parameter is given on the
    command line. This fixes a bug where the REPL would not start
    if `-v`, `-e` or `-l` where given.
  [#]# hslua-cli-1.4.0.1
  Released 2023-03-17.
  - Fix building on Windows.
  [#]# hslua-cli-1.4.0
  Released 2023-03-16.
  - Isocline-based REPL: interactive mode is now supported with
    the help of a new repl built with the isocline library.
  [#]# hslua-cli-1.3.0
  Released 2023-03-13.
  - Require hslua-core 2.3.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Sep 27 2022 Peter Simons <psimons@suse.com>
- Add hslua-cli at version 1.2.0.
